@@ -1,4 +1,4 @@
-#ident "$Id: mount.c,v 1.2 2003/09/10 14:27:41 raven Exp $"
+#ident "$Id: mount.c,v 1.3 2003/09/29 08:22:35 raven Exp $"
 /* ----------------------------------------------------------------------- *
  *   
  *  mount.c - Abstract mount code used by modules for an unexpected
@@ -20,40 +20,49 @@
  * ----------------------------------------------------------------------- */
 
 #include <syslog.h>
-#include <string.h>
 #include <stdlib.h>
+#include <string.h>
 #include "automount.h"
 
+#ifdef DEBUG
+#define DB(x)           do { x; } while(0)
+#else
+#define DB(x)           do { } while(0)
+#endif
+
 /* These filesystems are known not to work with the "generic" module */
 /* Note: starting with Samba 2.0.6, smbfs is handled generically.    */
 static char *not_generic[] = { "nfs", "ncpfs", "userfs", "afs",
-			       "autofs", "changer", "bind", NULL };
+	"autofs", "changer", "bind", NULL
+};
 
 int do_mount(const char *root, const char *name, int name_len,
 	     const char *what, const char *fstype, const char *options)
 {
-  struct mount_mod *mod;
-  const char *modstr;
-  char **ngp;
-  int rv;
+	struct mount_mod *mod;
+	const char *modstr;
+	char **ngp;
+	int rv;
 
-  mod = open_mount(modstr = fstype, NULL);
-  if ( !mod ) {
-    for ( ngp = not_generic ; *ngp ; ngp++ ) {
-      if ( !strcmp(fstype, *ngp) ) break;
-    }
-    if ( ! *ngp )
-      mod = open_mount(modstr = "generic", NULL);
-    if ( !mod ) {
-      syslog(LOG_ERR, "cannot find mount method for filesystem %s", fstype);
-      return -1;
-    }
-  }
-  syslog(LOG_DEBUG, "do_mount %s %s/%s type %s options %s using module %s",
-	 what, root, name, fstype, options, modstr);
+	mod = open_mount(modstr = fstype, NULL);
+	if (!mod) {
+		for (ngp = not_generic; *ngp; ngp++) {
+			if (!strcmp(fstype, *ngp))
+				break;
+		}
+		if (!*ngp)
+			mod = open_mount(modstr = "generic", NULL);
+		if (!mod) {
+			syslog(LOG_ERR, "cannot find mount method for filesystem %s",
+			       fstype);
+			return -1;
+		}
+	}
+	DB(syslog(LOG_DEBUG, "do_mount %s %s/%s type %s options %s using module %s",
+		  what, root, name, fstype, options, modstr));
 
-  rv = mod->mount_mount(root,name,name_len,what,fstype,options,mod->context);
-  close_mount(mod);
+	rv = mod->mount_mount(root, name, name_len, what, fstype, options, mod->context);
+	close_mount(mod);
 
-  return rv;
+	return rv;
 }
